<?php

namespace application\campus;

/**
 * @package application.lib.campus.campus_manager
 */
use common\libraries\WebApplication;
use common\libraries\Path;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Request;

/**
 * A campus manager
 *
 * @author Sven Vanpoucke
 * @author Theunis Ludwig
 */
class Manager extends WebApplication
{
    const APPLICATION_NAME = 'campus';

    const ACTION_BROWSE = 'infoboard';

    const ACTION_HOME = 'home';
    const ACTION_CAMPUS_ADMIN = 'campus_admin';
    const ACTION_TEACHERLIST = 'teacherlist';
    const ACTION_STUDENTLIST = 'studentlist';
    const ACTION_STUDENTTRACKING = 'studenttracking';
    const ACTION_STUDENTREPORT = 'studentreport';
    const ACTION_ROSTER = 'roster';
    const ACTION_STUDENTROSTER = 'studentroster';
    const ACTION_RESERVATIONROSTER = 'reservationroster';
    const ACTION_AGENDA = 'agenda';
    const ACTION_INFOBOARD = 'infoboard';
    const ACTION_OBJECTIVETRACKING = 'objectivetracking';
    const ACTION_IT_SUPPORT = 'it_support';

    const DEFAULT_ACTION = self :: ACTION_BROWSE;



    /**
     * Constructor
     *
     * @param User $user The current user
     */
    function __construct($user = null)
    {
        parent :: __construct($user);
//   $tdm = CampusDataManager :: get_instance();
//        $this->campus = new Campus();
//        $this->load_campus();
    }

//===========================

    function get_application_name()
    {
        return self :: APPLICATION_NAME;
    }


    function display_menu()
    {
        $html = array();
        $html[] = '<div id="tool_bar" class="tool_bar tool_bar_right">';

        $img_path = htmlspecialchars(Theme :: get_common_image_path());
        $html[] = '<div id="tool_bar_hide_container" class="hide">';
        $html[] = '<a id="tool_bar_hide" href="#"><img src="' . $img_path . 'action_action_bar_right_hide.png" /></a>';
        $html[] = '<a id="tool_bar_show" href="#"><img src="' . $img_path . 'action_action_bar_right_show.png" /></a>';
        $html[] = '</div>';

        $html[] = '<div class="tool_menu">';
        $html[] = '<ul>';

        $html[] = '<span class="menusectioncaption">' . Translation :: get("campusMenuCaption") . '</span>';
        $html[] = '<ul class="menulist">';
        $html[] =
            '<li><a href="' . $this->get_infoboard_url() . '" >' . Translation :: get("menuInfoBoard") . '</a></li>';
        if ($this->get_user()->is_teacher())
        {
// de berichten voor de personeelsleden...
            $html[] = '<li><a href="' . $this->get_infoboard_url() . '&page=editmessage&action=list" TITLE="' .
                Translation :: get("tooltipManageMsg") . '">' . Translation :: get("menu2MsgList") . '</A></li>';
        }
        $html[] =
            '<li><a href="' . $this->get_agenda_url() . '" title="' . Translation :: get("tooltipShowAgenda") . '">' .
            Translation :: get("menuAgenda") . '</A></li>';
        $html[] = '<li><a href="' . $this->get_studentroster_url() . '" title="' .
            Translation :: get("tooltipShowStudentRoster") . '">' .
            Translation :: get("menuStudentRoster") . '</A></li>';
        if ($this->get_user()->is_teacher())
        {
            $html[] = '<li><a href="' . $this->get_roster_url() . '" title="' .
                Translation :: get("tooltipShowTeacherRoster") . '">' .
                Translation :: get("menuTeacherRoster") . '</A></li>';
            $html[] = '<li><a href="' . $this->get_reservationroster_url() . '" title="' .
                Translation :: get("tooltipShowResourceRoster") . '">' .
                Translation :: get("menuReservRoster") . '</A></li>';
//echo ("<li><A href=\"".$_configuration['root_web']."plugin/campus/disciplineroster/index.php\" >".get_lang("menuDisciplineRoster")."</A></li>");
            $html[] = '<li><a href="' . $this->get_studentlist_url() . '" title="' .
                Translation :: get("tooltipShowClassLists") . '">' . Translation :: get("menuClassLists") . '</A></li>';
        }

        $html[] = '<li><a href="' . $this->get_teacherlist_url() . '" title="' .
            Translation :: get("tooltipShowTeacherlist") . '">' . Translation :: get("menuTeacherlist") . '</A></li>';
// check if IT devices exist in the database....
        if ($this->get_user()->is_teacher())
        {
            $html[] = '<li><a href="' . $this->get_objectivetracking_url() . '" title="' .
                Translation :: get("tooltipShowObjectiveTracking") . '">' .
                Translation :: get("menuObjectivetracking") . '</A></li>';
            $sql = "SELECT * FROM `campus_it_device` WHERE `department_id`=" . $_SESSION['_campus']['department_id'] . "
       	";
            $result = mysql_query($sql);
            if (mysql_num_rows($result) >= 1)
            {
                $html[] = '<li><a href="' . $this->get_it_support_url() . '" >' .
                    Translation :: get("menuITAdmin") . '</a></li>';
            }
            $sql = "SELECT *
        FROM `campus_rights`
	       WHERE `campus_rights`.`user_id` = " . $this->get_user_id() . " AND (
	       	`campus_rights`.`item` = 1 OR
	       	`campus_rights`.`item` = 2 OR
	       	`campus_rights`.`item` = 3 OR
	       	`campus_rights`.`item` = 4 OR
	       	`campus_rights`.`item` = 8
       	)";
            $result = mysql_query($sql);
            if ((mysql_num_rows($result) >= 1) || ($this->get_user()->is_platform_admin()))
            {
                $html[] = '<li>&nbsp</li>';
                $html[] = '<li><a href="' . $this->get_campus_admin_url() . '" >' .
                    Translation :: get("menuDepartmentAdmin") . '</a></li>';
            }
        }

        $html[] = '</ul>';

        $html[] = '</ul>';
        $html[] = '</div>';

        $html[] = '</div>';
        $html[] = '<script type="text/javascript" src="' . htmlspecialchars(Path :: get(WEB_LIB_PATH)) .
            'libraries/resources/javascript/tool_bar.js' . '"></script>';
        $html[] = '<div class="clear"></div>';

        return implode($html, "\n");
    }

// Data Retrieving
// Url Creation

    function get_browse_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_BROWSE));
    }

    function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

// test
    function get_campus_admin_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CAMPUS_ADMIN));
    }

    function get_teacherlist_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_TEACHERLIST));
    }

    function get_studentlist_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_STUDENTLIST));
    }

    function get_studenttracking_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_STUDENTTRACKING));
    }

    function get_studentreport_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_STUDENTREPORT));
    }

    function get_roster_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_ROSTER));
    }

    function get_studentroster_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_STUDENTROSTER));
    }

    function get_reservationroster_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_RESERVATIONROSTER));
    }

    function get_agenda_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_AGENDA));
    }

    function get_infoboard_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_INFOBOARD));
    }

    function get_objectivetracking_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_OBJECTIVETRACKING));
    }

    function get_it_support_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_IT_SUPPORT));
    }

    function get_mail_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_MAIL));
    }
}

?>